@@ -24,8 +24,18 @@ class Hasht(object):
     '''Hash Table For Consensus and MiniStock'''
     def __init__(self, dfp, dfc):
         # changing these to numpy matrix rather than pandas is faster
-        self.dfp = dfp
-        self.dfc = dfc
+        self.dfp = dfp.to_numpy()
+        self.dfc = dfc.to_numpy()
+        self.dfpd = {}
+        c=0
+        for i in list(dfp):
+            self.dfpd[i]=c
+            c+=1
+        self.dfcd={}
+        c=0
+        for i in list(dfc):
+            self.dfcd[i]=c
+            c+=1
         self.size = int((len(dfp)+len(dfc))*1.4)
         self.map = [None]*self.size
 
@@ -81,28 +91,26 @@ class Hasht(object):
         '''This itself removes redundancies via hashing'''
         import math
         for i in range(0, len(self.dfp)):
-            d = self.dfp.iloc[i]
-            if d.ministock_name != None:
-                if math.isnan(d.hb)==False:
-                    self.add(d.ministock_name,
-                             ['part',int(d.hb),d.trimmed_len, i])
+            d = self.dfp[i]
+            if d[self.dfpd['ministock_name']] != None:
+                if math.isnan(d[self.dfpd['hb']])==False:
+                    self.add(d[self.dfpd['ministock_name']],
+                             ['part',int(d[self.dfpd['hb']]),d[self.dfpd['trimmed_len']], i])
                 else:
-                    self.add(d.ministock_name,
-                             ['part',d.hb,d.trimmed_len, i])
+                    self.add(d[self.dfpd['ministock_name']],
+                             ['part',d[self.dfpd['hb']],d[self.dfpd['trimmed_len']], i])
             elif d.hb != None and math.isnan(d.hb)==False and d.hb!=0:
-                self.add(int(d.hb),
-                         ['part',d.hb,d.trimmed_len, i])
-            else:
-                print(d)
+                self.add(int(d[self.dfpd['hb']]),
+                         ['part',d[self.dfpd['hb']],d[self.dfpd['trimmed_len']], i])
         # by adding consensus last we can ensure that the hash is updated for cons over part
         for i in range(0, len(self.dfc)):
-            d = self.dfc.iloc[i]
-            if d.hb != None and math.isnan(d.hb)==False and d.hb!=0:
-                self.add(int(d.hb),
-                         ['cons',d.ministock_name,d.sequence_len, i])
+            d = self.dfc[i]
+            if d[self.dfcd['hb']] != None and math.isnan(d[self.dfcd['hb']])==False and d[self.dfcd['hb']]!=0:
+                self.add(int(d[self.dfcd['hb']]),
+                         ['cons',d[self.dfcd['ministock_name']],d[self.dfcd['sequence_len']], i])
             else:
-                self.add(d.ministock_name,
-                         ['cons',d.ministock_name,d.sequence_len, i])
+                self.add(d[self.dfcd['hb']],
+                         ['cons',d[self.dfcd['ministock_name']],d[self.dfcd['sequence_len']], i])
     def clean(self):
         '''This Matches Minis with their HB and removes partials if necessary'''
         import math
@@ -147,71 +155,71 @@ class Hasht(object):
                 for j in i:
                     if j[1][0] =='part':
                         md = 'partial'
-                        d = self.dfp.iloc[j[1][3]]
+                        d = self.dfp[j[1][3]]
                         try:
-                            l = len(d.trimmed_sequence)
+                            l = len(d[self.dfpd['trimmed_sequence']])
                         except:
                             l = 0
-                        if d.hb ==0:
+                        if d[self.dfpd['hb']] ==0:
                             hb = ''
                         else:
-                            hb = d.hb
+                            hb = d[self.dfpd['hb']]
                         nd.append([md,
-                                   d.date,
-                                   d.quality,
-                                   d.ministock_name,
+                                   d[self.dfpd['date']],
+                                   d[self.dfpd['quality']],
+                                   d[self.dfpd['ministock_name']],
                                    hb,
-                                   d.hd,
-                                   d.plate,
-                                   d.working_stocks,
-                                   d.species_1,
-                                   d.strain_1,
-                                   d.pct_1,
-                                   d.nucnuc_1,
-                                   d.species_2,
-                                   d.strain_2,
-                                   d.pct_2,
-                                   d.nucnuc_2,
-                                   d.media,
-                                   d.treatment,
-                                   d.enrichment,
+                                   d[self.dfpd['hd']],
+                                   d[self.dfpd['plate']],
+                                   d[self.dfpd['working_stocks']],
+                                   d[self.dfpd['species_1']],
+                                   d[self.dfpd['strain_1']],
+                                   d[self.dfpd['pct_1']],
+                                   d[self.dfpd['nucnuc_1']],
+                                   d[self.dfpd['species_2']],
+                                   d[self.dfpd['strain_2']],
+                                   d[self.dfpd['pct_2']],
+                                   d[self.dfpd['nucnuc_2']],
+                                   d[self.dfpd['media']],
+                                   d[self.dfpd['treatment']],
+                                   d[self.dfpd['enrichment']],
                                    l,
-                                   d.trimmed_ns,
-                                   d.trimmed_sequence,
+                                   d[self.dfpd['trimmed_ns']],
+                                   d[self.dfpd['trimmed_sequence']],
                                   ])
                     else:
                         md = 'consensus'
-                        d = self.dfc.iloc[j[1][3]]
+                        d = self.dfc[j[1][3]]
                         try:
-                            l = len(d.sequence)
+                            l = len(d[self.dfcd['sequence']])
                         except:
                             l = 0
-                        if d.hb ==0:
+                        if d[self.dfcd['hb']] ==0:
                             hb = ''
                         else:
-                            hb = d.hb
+                            hb = d[self.dfcd['hb']]
                         nd.append([md,
-                                   d.date,
-                                   d.quality,
-                                   d.ministock_name,
+                                   d[self.dfcd['date']],
+                                   d[self.dfcd['quality']],
+                                   d[self.dfcd['ministock_name']],
                                    hb,
-                                   d.hd,
-                                   d.plate,
-                                   d.working_stocks,
-                                   d.species_1,
-                                   d.strain_1,
-                                   d.pct_1,
-                                   d.nucnuc_1,
-                                   d.species_2,
-                                   d.strain_2,
-                                   d.pct_2,
-                                   d.nucnuc_2,
-                                   d.media,
-                                   d.treatment,
-                                   d.enrichment,
+                                   d[self.dfcd['hd']],
+                                   d[self.dfcd['plate']],
+                                   d[self.dfcd['working_stocks']],
+                                   d[self.dfcd['species_1']],
+                                   d[self.dfcd['strain_1']],
+                                   d[self.dfcd['pct_1']],
+                                   d[self.dfcd['nucnuc_1']],
+                                   d[self.dfcd['species_2']],
+                                   d[self.dfcd['strain_2']],
+                                   d[self.dfcd['pct_2']],
+                                   d[self.dfcd['nucnuc_2']],
+                                   d[self.dfcd['media']],
+                                   d[self.dfcd['treatment']],
+                                   d[self.dfcd['enrichment']],
                                    l,
-                                   d.sequence_ns,
-                                   d.sequence,
+                                   d[self.dfcd['sequence_ns']],
+                                   d[self.dfcd['sequence']],
                                   ])
         import pandas as pd
         return pd.DataFrame(nd,columns = ['type','date','quality','ministock_name','hb','plate','hd','working_stocks','species_1','strain_1','pct_1', 'nucnuc_1','species_2','strain_2','pct_2', 'nucnuc_2', 'media','treatment','enrichment','sequence_length','sequence_ns','sequence'])
